Changes
=======

0.2.1 (2017-02-06)
==================

- Fixed: Packing wasn't handled correctly. Objects removed during
  packing weren't removed from the ``newt`` table.


0.2.0 (2017-01-30)
==================

- Added PyPy support

- Fixed: ``datetime`` values with time zones weren't handled correctly.

0.1.2 (2017-01-26)
==================

- Fixed a number of documentation errors.

  (Documentation wasn't tested, but now is, thankd to `manuel
  <http://pythonhosted.org/manuel/>`_.)

- Added some missing names to ``newt.db``.

0.1.1 (2017-01-24)
==================

Fixed a small Python 2 bug that prevented import.

0.1.0 (2017-01-24)
==================

Initial release
